

from __future__ import print_function, unicode_literals, absolute_import, division
from reahl.doc.examples.tutorial.sessionscope.sessionscope import SessionScopeUI

web.site_root = SessionScopeUI
